#include <SPI.h>
#include <LoRa.h>

//Libraries for OLED Display
#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>


#include <WiFi.h>
#include "time.h"



//OLED pins
#define OLED_SDA 4
#define OLED_SCL 15 
#define OLED_RST 16
#define SCREEN_WIDTH 128 // OLED display width, in pixels
#define SCREEN_HEIGHT 32 // OLED display height, in pixels




const char* ssid       = "XXXXXXXXXXXXXXXXXX";
const char* password   = "XXXXXXXXXXXXXXXXXX";

const char* ntpServer = "pool.ntp.org";
const long  gmtOffset_sec = -3600;
const int   daylightOffset_sec = 3600;



int H = 0;
int M = 0;
int S = 0;
int x = 0;
Adafruit_SSD1306 display(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, -1);





void printLocalTime()
{
  struct tm timeinfo;
  if(!getLocalTime(&timeinfo)){
    Serial.println("Failed to obtain time");
    return;
  }
  Serial.println(&timeinfo, "%A, %B %d %Y %H:%M:%S");
  H = timeinfo.tm_hour;
  M = timeinfo.tm_min;
  S = timeinfo.tm_sec;
  x = timeinfo.tm_isdst;
  
  Serial.println(x);
}

void setup()
{

  //reset OLED display via software
  pinMode(OLED_RST, OUTPUT);
  digitalWrite(OLED_RST, LOW);
  delay(20);
  digitalWrite(OLED_RST, HIGH);

  //initialize OLED
  Serial.begin(115200);
  
  //connect to WiFi
  Serial.printf("Connecting to %s ", ssid);
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) {
      delay(500);
      Serial.print(".");
  }
  Serial.println(" CONNECTED");
  
  //init and get the time
  configTime(gmtOffset_sec, daylightOffset_sec, ntpServer);
  printLocalTime();

  //disconnect WiFi as it's no longer needed
  WiFi.disconnect(true);
  WiFi.mode(WIFI_OFF);



  ////////////////////////////////
  if(!display.begin(SSD1306_SWITCHCAPVCC, 0x3C,4,15)) { // Address 0x3C for 128x32
    Serial.println(F("SSD1306 allocation failed"));
    for(;;); // Don't proceed, loop forever
  }
  
  display.clearDisplay();
  display.setTextColor(WHITE);
  display.setTextSize(3);
  display.setCursor(0,0);
  display.print("LORA SENDER ");
  display.display();
  
  //initialize Serial Monitor
  Serial.begin(115200);
  
}

void loop()
{
  display.clearDisplay();
  display.setCursor(0,0);
  display.println(H);
  display.setCursor(30,0);
  display.println(":");
  display.setCursor(40,0);
  display.println(M);
  display.setCursor(70,0);
  display.println(":");
  display.setCursor(90,0);
  display.println(S);       
  display.display();
  
  delay(1000);
  printLocalTime();
}
